<?php

namespace Ardent\PicnicApi\Objects;

class Decorators
{
    public const IMMUTABLE = 'IMMUTABLE';
    public const QUANTITY = 'QUANTITY';
    public const UNIT_QUANTITY = 'UNIT_QUANTITY';
    public const FRESH_LABEL = 'FRESH_LABEL';

    private array $decorators = [];

    public function __construct(array $rawDecorators)
    {
        foreach ($rawDecorators as $rawDecorator) {
            $this->decorators[$rawDecorator['type']] = $rawDecorator;
        }
    }

    public function getDecorator(string $type): ?array
    {
        return $this->decorators[$type] ?? null;
    }

    public function hasDecorator(string $type): bool
    {
        return isset($this->decorators[$type]);
    }

    public function getQuantity(): string
    {
        $quantity = $this->getDecorator(self::QUANTITY);
        return $quantity ? $quantity['quantity'] : '-';
    }

    public function getFreshLabel(): string
    {
        $label = $this->getDecorator(self::FRESH_LABEL);
        if (!$label) {
            return '-';
        }
        return match ($label['period']) {
            'P2D' => 'minimal 2 days',
            'P3D' => 'minimal 3 days',
            'P4D' => 'minimal 4 days',
            'P5D' => 'minimal 5 days',
            'P7D' => 'minimal 7 days',
            default => 'unknown period ' . $label['period'],
        };
    }

    public function getRawDecorators(): array
    {
        return $this->decorators;
    }
}