<?php


namespace Ardent\PicnicApi\Objects;


use Ardent\PicnicApi\Client;

class OrderArticle extends AbstractApiObject implements ArticleInterface
{
    /**
     * OrderArticle constructor.
     */
    public function __construct(
        private string     $id,
        private string     $name,
        private array      $imageIds,
        private string     $unitQuantity,
        private string     $unitQuantitySub,
        private int        $price,
        private int        $maxCount,
        private Decorators $decorators,
    )
    {
    }

    static public function getType(): string
    {
        return 'ORDER_ARTICLE';
    }

    static public function fromApi(array $apiObject): AbstractApiObject
    {
        dump($apiObject);
        return new self(
            $apiObject['id'],
            $apiObject['name'],
            $apiObject['image_ids'],
            $apiObject['unit_quantity'],
            $apiObject['unit_quantity_sub'] ?? 'n/a',
            $apiObject['price'],
            $apiObject['max_count'],
            new Decorators($apiObject['decorators']),
        );
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $size one of tiny/small/medium/large/extra-large
     *
     * @return string[]
     */
    public function getImageUrls(string $size = 'medium'): array
    {
        return array_map(function ($id) use ($size) {
            return Client::getImageUri($id, $size);
        }, $this->imageIds);
    }

    public function getImageId(): string
    {
        return $this->imageIds[0];
    }

    public function getImageUrl(string $size = 'medium'): string
    {
        return Client::getImageUri($this->getImageId(), $size);
    }

    public function getUnitQuantity(): string
    {
        return $this->unitQuantity;
    }

    public function getUnitQuantitySub(): string
    {
        return $this->unitQuantitySub;
    }

    public function getPrice(): float
    {
        return $this->price / 100.0;
    }

    public function getMaxCount(): int
    {
        return $this->maxCount;
    }

    public function getDecorators(): Decorators
    {
        return $this->decorators;
    }
}