<?php


namespace Ardent\PicnicApi\Objects;


use Ardent\PicnicApi\Client;

class SingleArticle extends AbstractApiObject implements ArticleInterface
{
    static public function getType(): string
    {
        return 'SINGLE_ARTICLE';
    }

    /**
     * SingleArticle constructor.
     */
    public function __construct(
        private string     $id,
        private string     $name,
        private int        $price,
        private int        $displayPrice,
        private string     $imageId,
        private int        $maxCount,
        private string     $unitQuantity,
        private string     $unitQuantitySub,
        private Decorators $decorators,
    )
    {
    }

    static public function fromApi(array $apiObject): self
    {
        return new self(
            $apiObject['id'],
            $apiObject['name'],
            $apiObject['price'] ?? 0,
            $apiObject['display_price'],
            $apiObject['image_id'],
            $apiObject['max_count'],
            $apiObject['unit_quantity'],
            $apiObject['unit_quantity_sub'] ?? 'n/a',
            new Decorators($apiObject['decorators']),
        );
    }

    public function getId(): string
    {
        return $this->id;
    }

    public function getName(): string
    {
        return $this->name;
    }

    public function getPrice(): float
    {
        return $this->price / 100.0;
    }

    public function getDisplayPrice(): float
    {
        return $this->displayPrice / 100.0;
    }

    public function getImageId(): string
    {
        return $this->imageId;
    }

    public function getImageUrl(string $size = 'medium'): string
    {
        return Client::getImageUri($this->imageId, $size);
    }

    public function getMaxCount(): int
    {
        return $this->maxCount;
    }

    public function getUnitQuantity(): string
    {
        return $this->unitQuantity;
    }

    public function getUnitQuantitySub(): string
    {
        return $this->unitQuantitySub;
    }

    public function getDecorators(): Decorators
    {
        return $this->decorators;
    }
}