<?php


namespace Ardent\PicnicApi\Objects;


use Ardent\PicnicApi\Client;

class SingleArticleDetails extends AbstractApiObject implements ArticleInterface
{
    static public function getType(): string
    {
        return 'SINGLE_ARTICLE_DETAILS';
    }

    public function __construct(
        private string     $id,
        private string     $name,
        private int        $price,
        private int        $displayPrice,
        private int        $deposit,
        private string     $imageId,
        private array      $imageIds,
        private int        $maxCount,
        private string     $unitQuantity,
        private string     $unitQuantitySub,
        private Decorators $decorators,
        private array      $nutritionalValues,
        private string     $ingredientsBlob,
        private string     $additionalInfo,
    )
    {
    }

    static public function fromApi(array $apiObject): self
    {
        return new self(
            $apiObject['id'],
            $apiObject['name'],
            $apiObject['price'] ?? 0,
            $apiObject['display_price'],
            $apiObject['deposit'] ?? 0,
            $apiObject['image_id'],
            $apiObject['image_ids'],
            $apiObject['max_count'],
            $apiObject['unit_quantity'],
            $apiObject['unit_quantity_sub'] ?? 'n/a',
            new Decorators($apiObject['decorators']),
            $apiObject['nutritional_values'],
            $apiObject['ingredients_blob'] ?? '',
            $apiObject['additional_info'],
        );
    }

    /**
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    public function getPrice(): float
    {
        return $this->price / 100.0;
    }

    public function getDisplayPrice(): float
    {
        return $this->displayPrice / 100.0;
    }

    public function getDeposit(): float
    {
        return $this->deposit / 100.0;
    }

    /**
     * @return string
     */
    public function getImageId(): string
    {
        return $this->imageId;
    }

    public function getImageUrl(string $size = 'medium'): string
    {
        return Client::getImageUri($this->imageId, $size);
    }

    /**
     * @return array
     */
    public function getImageIds(): array
    {
        return $this->imageIds;
    }

    /**
     * @param string $size one of tiny/small/medium/large/extra-large
     *
     * @return string[]
     */
    public function getImageUrls(string $size = 'medium'): array
    {
        return array_map(function ($id) use ($size) {
            return Client::getImageUri($id, $size);
        }, $this->imageIds);
    }

    public function getMaxCount(): int
    {
        return $this->maxCount;
    }

    public function getUnitQuantity(): string
    {
        return $this->unitQuantity;
    }

    public function getUnitQuantitySub(): string
    {
        return $this->unitQuantitySub;
    }

    public function getDecorators(): Decorators
    {
        return $this->decorators;
    }

    public function getNutritionalValues(): array
    {
        return $this->nutritionalValues;
    }

    public function getIngredientsBlob(): string
    {
        return $this->ingredientsBlob;
    }

    public function getAdditionalInfo(): string
    {
        return $this->additionalInfo;
    }
}